Changelog
=========

0.1.6
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- (config) Improved get_odoo_params_list



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Automatically generate changelog through cliff

- Add pypi badge


0.1.5
----------


Fixed
~~~~~~~~~~~~~~~~~~~~~

- Db params need a underscore


0.1.4
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- Better help screen for cli tool

- (db) Move drop_db into own function


0.1.3
----------


Fixed
~~~~~~~~~~~~~~~~~~~~~

- List-db was printed twice



Testing
~~~~~~~~~~~~~~~~~~~~~

- Fix path on windows


0.1.2
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- (db) List db added



Fixed
~~~~~~~~~~~~~~~~~~~~~

- Path for windows

- Use a more robust approach


0.1.1
----------


Added
~~~~~~~~~~~~~~~~~~~~~

- (db) Allow drop_db and create_db without sudo



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Fix build

- Fix documentation



Testing
~~~~~~~~~~~~~~~~~~~~~

- Update codecov



Miscellaneous
~~~~~~~~~~~~~~~~~~~~~

- Add codecov workflow

- Add readthedocs.yml

- Fix pre-commit

- Fix actions

- Add codecov badge


0.1.0
----------


Fixed
~~~~~~~~~~~~~~~~~~~~~

- Not working parameter in install removed



Documentation
~~~~~~~~~~~~~~~~~~~~~

- Add cli doc



Refactor
~~~~~~~~~~~~~~~~~~~~~

- Remove obsolete function from config_loader



Miscellaneous
~~~~~~~~~~~~~~~~~~~~~

- Initial release

- Pre-commit and readme cleanup
